pub async fn expect_create<T: ActorEntity>(
receiver: &mut Receiver<ResourceRequest<T>>,
) -> Option<(T::Create, Sender<Result<T::Id, FrameworkError>>)>Expand description
Helper to verify that the next message is a Create request
pub async fn expect_create<T: ActorEntity>(
receiver: &mut Receiver<ResourceRequest<T>>,
) -> Option<(T::Create, Sender<Result<T::Id, FrameworkError>>)>Helper to verify that the next message is a Create request