pub async fn expect_get<T: ActorEntity>(
receiver: &mut Receiver<ResourceRequest<T>>,
) -> Option<(T::Id, Sender<Result<Option<T>, FrameworkError>>)>Expand description
Helper to verify that the next message is a Get request
pub async fn expect_get<T: ActorEntity>(
receiver: &mut Receiver<ResourceRequest<T>>,
) -> Option<(T::Id, Sender<Result<Option<T>, FrameworkError>>)>Helper to verify that the next message is a Get request